# Random Code

## TABLE OF CONTENT 
* [Introduction](#introduction)
* [Installation](#installation)       
* [Usage](#usage)



## Introduction

Function to generate random code string. Defaulted at 20 characters.

## Installation

Can be installed using pip.

``` pip install pycodecreator ```

## Usage

```from codegenerator import codegenerator```

Then use module as:

```codegenerator.code()```

Can also specify code length:

e.g ``` codegenerator.code(10) ```

